@@ -32,7 +32,9 @@ execJob.JobCollection = function(job) {
 
 #' @export
 execJob.Job = function(job) {
-  local_options(list(error = function(e) traceback(2L)))
+  opts = options("error")
+  options(error = function(e) traceback(2L))
+  on.exit(options(opts))
   messagef("### [bt%s]: Setting seed to %i ...", now(), job$id, job$seed)
   if (".job" %chin% names(formals(job$fun))) {
     with_seed(job$seed, do.call(job$fun, c(job$pars, list(.job = job)), envir = .GlobalEnv))
@@ -43,7 +45,9 @@ execJob.Job = function(job) {
 
 #' @export
 execJob.Experiment = function(job) {
-  local_options(list(error = function(e) traceback(2L)))
+  opts = options("error")
+  options(error = function(e) traceback(2L))
+  on.exit(options(opts))
   messagef("### [bt%s]: Generating problem instance for problem '%s' ...", now(), job$prob.name)
   instance = job$instance
   force(instance)
